"lmom.test.gpa" <-
function(data) {
   lmom <- lmom.ub(data)
   para <- pargpa(lmom)
   cat("GENERALIZED PARETO DISTRIBUTION PARAMETERS\n")
   str(para)
   lmompara <- lmomgpa(para)
   Q50 <- quagpa(0.5,para)
   cat(c("Computed median=",Q50,"\n"),sep="")
   P50 <- cdfgpa(Q50,para)
   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
   lmom.diff(lmompara,lmom)
}

